==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_fr_tu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=fr_tu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Bienvenue @nom@ !',
	'c_accueil_configurer_site' => 'Configurer ton site',
	'c_accueil_configurer_site_texte' => 'Une des premières choses à faire est de donner un nom à ton site.
Il se nomme actuellement « @nom@ ». Le nom du site est affiché tout en haut de cette page.
En cliquant dessus, tu pourras modifier son nom, mais aussi lui donner un logo et un slogan.',
	'c_accueil_publication' => 'Publie !',
	'c_accueil_publication_texte' => 'Pour publier une page, il te faudra créer un article.
Il est nécessaire pour cela de créer au moins une rubrique. Tu peux le faire dans le menu « Édition » en cliquant « Rubriques ».',
	'c_accueil_texte' => 'Tu viens d’entrer dans l’espace privé de SPIP.',
	'c_accueil_texte_revenir' => 'Cette page présente l’activité éditoriale récente sur ton site.
Tu peux revenir sur cette page à tout instant en cliquant l’icône de maison,
sur la partie haute, sous ton nom.',
	'c_article_redaction' => 'L’article est en cours de rédaction',
	'c_article_redaction_redacteur' => 'L’article est en cours de rédaction',
	'c_article_redaction_redacteur_texte' => 'Pour proposer ton article aux administrateurs du site et aux autres rédacteurs, dans le cadre sur le côté, change « en cours de rédaction » par « proposé à la publication ».',
	'c_article_redaction_texte' => 'Pour publier cet article sur le site public, il faut changer son statut.
Dans le cadre sur le côté, change « en cours de rédaction » par « publié en ligne ».',
	'c_articles_creer' => 'Comment créer un article ?',
	'c_articles_creer_texte' => 'Tu ne pourras créer un article depuis cette page qu’à partir du moment où il existe une rubrique dans ton site.
Tu peux la créer depuis le menu « Édition », puis « Rubriques ».',
	'c_job' => 'Les travaux à faire…',
	'c_job_texte' => 'Cette page liste les prochaines tâches de maintenance que doit effectuer SPIP. Ces tâches sont exécutées à intervalle régulier ou ponctuellement pour des traitements lourds demandés par des plugins, tel que l’envoi d’email en masse.',
	'c_rubrique_publier' => 'Crée un article',
	'c_rubrique_publier_texte' => 'Une rubrique n’est visible sur le site public qu’à partir du moment où elle contient au moins un contenu publié ; par exemple : un article publié.
Crée donc un article. Tu peux le faire depuis cette page, sous le descriptif de ta rubrique.',
	'c_rubriques_creer' => 'Crée une première rubrique !',
	'c_rubriques_creer_texte' => 'Les rubriques sont la structure de base du site ; tu pourras créer des articles dans chacune d’entre elles.
Commence par créer une première rubrique.',

	// E
	'explication_activer_compagnon' => 'Le compagnon ajoute des commentaires sur certaines pages
de l’espace privé pour aider à prendre SPIP en main. Souhaites-tu l’activer ?',
	'explication_reinitialiser_compagnon' => 'Les messages déjà vus par un auteur ne sont plus affichés ensuite.
Souhaites-tu réinitialiser ces messages ?',

	// L
	'label_activer_compagnon' => 'Activer le compagnon ?',
	'label_reinitialiser_compagnon' => 'Réinitialiser les messages du compagnon ?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Bien !',
	'ok_jai_compris' => 'J’ai compris !',
	'ok_merci' => 'Merci',
	'ok_parfait' => 'Parfait !',

	// R
	'reinitialisation' => 'Réinitialisation',
	'reinitialisation_ok' => 'La réinitialisation est effectuée.',
	'reinitialiser' => 'Réinitialiser',
	'reinitialiser_moi' => 'Oui, uniquement ceux que j’ai déjà lu',
	'reinitialiser_tous' => 'Oui, quel que soit l’auteur',

	// T
	'titre_compagnon' => 'Le Compagnon',
	'titre_page_configurer_compagnon' => 'Configurer le Compagnon'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_fr_tu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=fr_tu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Bienvenue @nom@ !',
	'c_accueil_configurer_site' => 'Configurer ton site',
	'c_accueil_configurer_site_texte' => 'Une des premières choses à faire est de donner un nom à ton site.
Il se nomme actuellement « @nom@ ». Le nom du site est affiché tout en haut de cette page.
En cliquant dessus, tu pourras modifier son nom, mais aussi lui donner un logo et un slogan.',
	'c_accueil_publication' => 'Publie !',
	'c_accueil_publication_texte' => 'Pour publier une page, il te faudra créer un article.
Il est nécessaire pour cela de créer au moins une rubrique. Tu peux le faire dans le menu « Édition » en cliquant « Rubriques ».',
	'c_accueil_texte' => 'Tu viens d’entrer dans l’espace privé de SPIP.',
	'c_accueil_texte_revenir' => 'Cette page présente l’activité éditoriale récente sur ton site.
Tu peux revenir sur cette page à tout instant en cliquant l’icone de maison,
sur la partie haute, sous ton nom.',
	'c_article_redaction' => 'L’article est en cours de rédaction',
	'c_article_redaction_redacteur' => 'L’article est en cours de rédaction',
	'c_article_redaction_redacteur_texte' => 'Pour proposer ton article aux administrateurs du site et aux autres rédacteurs, dans le cadre sur le côté, change « en cours de rédaction » par « proposé à la publication ».',
	'c_article_redaction_texte' => 'Pour publier cet article sur le site public, il faut changer son statut.
Dans le cadre sur le côté, change « en cours de rédaction » par « publié en ligne ».',
	'c_articles_creer' => 'Comment créer un article ?',
	'c_articles_creer_texte' => 'Tu ne pourras créer un article depuis cette page qu’à partir du moment où il existe une rubrique dans ton site.
Tu peux la créer depuis le menu « Édition », puis « Rubriques ».',
	'c_job' => 'Les travaux à faire…',
	'c_job_texte' => 'Cette page liste les prochaines tâches de maintenance que doit effectuer SPIP. Ces tâches sont exécutées à intervalle régulier ou ponctuellement pour des traitements lourds demandés par des plugins, tel que l’envoi d’email en masse.',
	'c_rubrique_publier' => 'Crée un article',
	'c_rubrique_publier_texte' => 'Une rubrique n’est visible sur le site public qu’à partir du moment où elle contient au moins un contenu publié ; par exemple : un article publié.
Crée donc un article. Tu peux le faire depuis cette page, sous le descriptif de ta rubrique.',
	'c_rubriques_creer' => 'Crée une première rubrique !',
	'c_rubriques_creer_texte' => 'Les rubriques sont la structure de base du site ; tu pourras créer des articles dans chacune d’entre elles.
Commence par créer une première rubrique.',
	'c_sites_creer' => 'Comment créer ou importer un site ?',
	'c_sites_creer_texte' => 'Tu ne peux créer ou importer un site depuis cette page
		qu’à partir du moment où il existe une rubrique dans ton site.
		Tu peux la créer depuis le menu « Édition », puis « Rubriques ».',

	// E
	'explication_activer_compagnon' => 'Le compagnon ajoute des commentaires sur certaines pages
de l’espace privé pour aider à prendre SPIP en main. Souhaites-tu l’activer ?',
	'explication_reinitialiser_compagnon' => 'Les messages déjà vus par un auteur ne sont plus affichés ensuite.
Souhaites-tu réinitialiser ces messages ?',

	// L
	'label_activer_compagnon' => 'Activer le compagnon ?',
	'label_reinitialiser_compagnon' => 'Réinitialiser les messages du compagnon ?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Bien !',
	'ok_jai_compris' => 'J’ai compris !',
	'ok_merci' => 'Merci',
	'ok_parfait' => 'Parfait !',

	// R
	'reinitialisation' => 'Réinitialisation',
	'reinitialisation_ok' => 'La réinitialisation est effectuée.',
	'reinitialiser' => 'Réinitialiser',
	'reinitialiser_moi' => 'Oui, uniquement ceux que j’ai déjà lu',
	'reinitialiser_tous' => 'Oui, quel que soit l’auteur',

	// T
	'titre_compagnon' => 'Le Compagnon',
	'titre_page_configurer_compagnon' => 'Configurer le Compagnon'
);

?>
